==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","ءǢ");
define("_NOCOMMENTS","դ");
define("_UCOMMENT","");
define("_REVIEWS","Ԩó");
define("_SEARCHUSERS"," ҹż");
define("_SEARCHSECTIONS","  ");
define("_SEARCHREVIEWS","㹢 õǨͺ");
define("_SEARCHIN","");
define("_ARTICLES","");
define("_ALLAUTHORS","¹ء");
define("_ALL","");
define("_WEEK","ѻ");
define("_WEEKS","ѻ");
define("_MONTH","͹");
define("_MONTHS","͹");
define("_SEARCHON",":");
define("_SSTORIES","ͧ");
define("_SSECTIONS","");
define("_SUSERS","");
define("_NOMATCHES","辺ŵç͹");
define("_PREVMATCHES"," ҹ");
define("_NEXTMATCHES"," ͢ҧ˹");
define("_INSECTION","㹻");
define("_NONAME","͡");
define("_SCOMMENTS","");
define("_SEARCHRESULTS","šä");
define("_CONTRIBUTEDBY","");
define("_UCOMMENTS","й");
define("_MATCHTITLE","ç ͧ");
define("_MATCHTEXT","çͧ");
define("_MATCHBOTH","çͧ  ͧ");
define("_SREPLY","ͺѺ");
define("_SREPLIES","ͺѺ");
define("_ATTACHART","ǡҡѺ");
define("_PAGES","˹");
define("_REVIEWSCORE","ṹѺйӹ");
define("_PAGE","Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","ءǢ");
define("_NOCOMMENTS","դ");
define("_UCOMMENT","");
define("_REVIEWS","Ԩó");
define("_SEARCHUSERS"," ҹż");
define("_SEARCHSECTIONS","  ");
define("_SEARCHREVIEWS","㹢 õǨͺ");
define("_SEARCHIN","");
define("_ARTICLES","");
define("_ALLAUTHORS","¹ء");
define("_ALL","");
define("_WEEK","ѻ");
define("_WEEKS","ѻ");
define("_MONTH","͹");
define("_MONTHS","͹");
define("_SEARCHON",":");
define("_SSTORIES","ͧ");
define("_SSECTIONS","");
define("_SUSERS","");
define("_NOMATCHES","辺ŵç͹");
define("_PREVMATCHES"," ҹ");
define("_NEXTMATCHES"," ͢ҧ˹");
define("_INSECTION","㹻");
define("_NONAME","͡");
define("_SCOMMENTS","");
define("_SEARCHRESULTS","šä");
define("_CONTRIBUTEDBY","");
define("_UCOMMENTS","й");
define("_MATCHTITLE","ç ͧ");
define("_MATCHTEXT","çͧ");
define("_MATCHBOTH","çͧ  ͧ");
define("_SREPLY","ͺѺ");
define("_SREPLIES","ͺѺ");
define("_ATTACHART","ǡҡѺ");
define("_PAGES","˹");
define("_REVIEWSCORE","ṹѺйӹ");
define("_PAGE","Page");

?>
